/**
 * CSelect
 * @author Tevin
 */

<template>
    <view class="c-select">
        <picker
            mode="selector"
            :range="range"
            :value="current"
            @change="evt=>handleChange(evt.detail)"
        >
            <AtInput
                ref="input"
                :name="itemData.name"
                :title="itemData.label"
                :required="itemData.required"
                :error="itemData.error"
                :placeholder="placeholder"
                :value="selected"
            >
                <view class="at-icon at-icon-chevron-right" />
            </AtInput>
        </picker>
    </view>
</template>

<script>
import { AtInput } from 'taro-ui-vue';
import './cSelect.scss';

export default {
    name: 'CSelect',
    components: {
        AtInput,
    },
    props: {
        options: Array,
        placeholder: String,
        itemData: Object,
    },
    data() {
        return {
            optionKey: typeof this.options[0].value === 'undefined' ? 'id' : 'value',
        };
    },
    computed: {
        range() {
            return (this.options || []).map((item) => item.name || item[this.optionKey]);
        },
        current() {
            const curVal = this.itemData.formData[this.itemData.name];
            for (let i = 0, item; (item = this.options[i]); i++) {
                if (curVal === item[this.optionKey]) {
                    return i;
                }
            }
            return -1;
        },
        selected() {
            const curVal = this.itemData.formData[this.itemData.name];
            for (let i = 0, item; (item = this.options[i]); i++) {
                if (curVal === item[this.optionKey]) {
                    return item.name;
                }
            }
            return '';
        },
    },
    methods: {
        handleChange(evt) {
            const item = this.options[evt.value];
            this.itemData.onChange(item[this.optionKey]);
        },
    },
    mounted() {},
};
</script>